@@ -14,7 +14,7 @@ See (https://github.com/Ne-oL/geoz) for complete documentation (under constructi
 #
 # Author: Khalid ElHaj <KG.Khair@Gmail.com>
 #
-# License: GNU AGPL-3.0 license
+# License: BSD 3 clause license
 
 import math
 import copy
@@ -74,8 +74,8 @@ def convex_hull_plot(latlong, y_pred, grid_resolution=100, colormap='Set3'):
     data = pd.DataFrame({'X':latlong['LONGITUDE'], 'Y':latlong['LATITUDE'], 'cluster':y_pred})
     datagroup = data.groupby('cluster')
     count=datagroup.count()[['X']].rename(columns={'X':'Number of Points'})
-    print(count)
     print('Note: Clusters containing less than 3 points will be removed as Convex hull needs 3 points Minimum to be drawn')
+    print(count)
     data = datagroup.filter(lambda x: x.count().X >= 2)
 
     # Get the unique values in the cluster column
@@ -110,7 +110,7 @@ def convex_hull_plot(latlong, y_pred, grid_resolution=100, colormap='Set3'):
 
 
 
-def sklearn_plot(latlong, y_pred, C=100, gamma=30.0, grid_resolution=100, colormap='Set3', show_points=True, bazel=False, n_samples='default', extent=1, random_seed=None):
+def sklearn_plot(latlong, y_pred, C=100, gamma=30.0, grid_resolution=100, colormap='Set3', crs=None, show_points=False, bazel=False, n_samples='default', extent=1, random_seed=None):
     '''
     This Function utilize Scikit-Learn's "DecisionBoundaryDisplay" (http://scikit-learn.org) to draw the map. 
     The advantage of this method is that it gives the user a lot of flexibility to modify and adjust the map 
@@ -152,8 +152,13 @@ def sklearn_plot(latlong, y_pred, C=100, gamma=30.0, grid_resolution=100, colorm
         
     colormap : str or Colormap, optional
         A Colormap instance or registered colormap name. The colormap maps the level values to colors. 
-        Defaults to "Set3".  
+        Defaults to "Set3".
         
+    crs : str , optional
+        Coordinate Reference System of the Study Area you want to model. if you do not know yours, you can visit the 
+        EPSG website (https://spatialreference.org/ref/epsg/) and search for the appropriate authority string for your area, 
+        it should be a string like (eg "EPSG:4326") or a WKT string.
+
     show_points : bool, default True
         Display the points used to create the Decision Boundary. This would allow the user to check the accuracy of the model
         as well as any artifacts or missing clusters, thus alerting the user to enable bazel_cluster function.
@@ -189,7 +194,7 @@ def sklearn_plot(latlong, y_pred, C=100, gamma=30.0, grid_resolution=100, colorm
     
     
     fig, ax = plt.subplots()
-    clf = SVC(C=C, gamma=gamma, random_state=42)
+    clf = SVC(C=C, gamma=gamma, random_state=random_seed)
     
     # Creating the Bazel
     X=latlong[['LONGITUDE','LATITUDE']]
@@ -216,7 +221,7 @@ def sklearn_plot(latlong, y_pred, C=100, gamma=30.0, grid_resolution=100, colorm
     #Points for GroundTruth
     if show_points==True:
         #Convert the Points into Geometery file compatible with GeoPandas, then assign it correct coordinated and reproject it to similar projection to the shapefile (Basins)
-        gdf = gpd.GeoDataFrame(latlong, geometry=gpd.points_from_xy(latlong.LONGITUDE, latlong.LATITUDE))
+        gdf = gpd.GeoDataFrame(latlong, geometry=gpd.points_from_xy(latlong.LONGITUDE, latlong.LATITUDE, crs=crs))
         gdf.plot( marker='o',  color='red', markersize=50, ax=ax)
 
     return ax
@@ -290,7 +295,7 @@ def mlx_plot(latlong, y_pred, C=100, gamma=30.0, bazel=False, n_samples='default
     '''
 
     fig, ax = plt.subplots()
-    clf = SVC(C=C, gamma=gamma, random_state=42)
+    clf = SVC(C=C, gamma=gamma, random_state=random_seed)
     
     # Creating the Bazel
     X=latlong[['LONGITUDE','LATITUDE']]
@@ -384,10 +389,11 @@ def bazel_cluster(X,y,n_samples='default', extent=1, random_seed=None):
             long.append(pointLong)
     dataset=pd.DataFrame({'LONGITUDE': long,'LATITUDE': lat})
     dataset['y']=np.array(y).max()+1
+    #dataset['y']='bazel'
     Y=copy.deepcopy(y)
     Y.extend(dataset['y'].values)
     dataset=dataset[['LONGITUDE','LATITUDE']]
     X=pd.concat((X, dataset), axis=0,ignore_index= True)
     return X,Y
     
-__all__ = [ "sklearn_plot", "mlx_plot"]
\ No newline at end of file
+__all__ = [ "sklearn_plot", "mlx_plot", "convex_hull_plot"]
\ No newline at end of file
